from typesafe_parmap.parmap import par_map_2
from typesafe_parmap.parmap import par_map_3
from typesafe_parmap.parmap import par_map_4
from typesafe_parmap.parmap import par_map_5
from typesafe_parmap.parmap import par_map_6
from typesafe_parmap.parmap import par_map_7
from typesafe_parmap.parmap import par_map_8
from typesafe_parmap.parmap import par_map_9
from typesafe_parmap.parmap import par_map_10
from typesafe_parmap.parmap import par_map_11
from typesafe_parmap.parmap import par_map_12
from typesafe_parmap.parmap import par_map_13
from typesafe_parmap.parmap import par_map_14
from typesafe_parmap.parmap import par_map_15
from typesafe_parmap.parmap import par_map_16
from typesafe_parmap.parmap import par_map_17
from typesafe_parmap.parmap import par_map_18
from typesafe_parmap.parmap import par_map_19
from typesafe_parmap.parmap import par_map_20
from typesafe_parmap.parmap import par_map_21
from typesafe_parmap.parmap import par_map_22
from typesafe_parmap.parmap import par_map_n
from typesafe_parmap.parmap_timeout import *
from typesafe_parmap.parmap_timeout_n import *
from typesafe_parmap.named_thunk import NamedThunk
